@@ -355,10 +355,18 @@ class MessageTests(TestCase):
         # The url property must exist and defaults to None
         self.assertIsNone(message.Message().url)
 
+    def test_app_name(self):
+        # The app_name property must exist and defaults to None
+        self.assertIsNone(message.Message().app_name)
+
     def test_app_icon(self):
         # The app_icon property must exist and defaults to None
         self.assertIsNone(message.Message().app_icon)
 
+    def test_agent_name(self):
+        # The agent_name property must exist and defaults to None
+        self.assertIsNone(message.Message().agent_name)
+
     def test_agent_avatar(self):
         # The agent_avatar property must exist and defaults to None
         self.assertIsNone(message.Message().agent_avatar)
@@ -367,6 +375,10 @@ class MessageTests(TestCase):
         # The usenames property must exist and be a list
         self.assertEqual(message.Message().usernames, [])
 
+    def test_groups(self):
+        # The groups property must exist and be a list
+        self.assertEqual(message.Message().groups, [])
+
     def test_packages(self):
         # The packages property must exist and be a list
         self.assertEqual(message.Message().packages, [])
@@ -400,6 +412,13 @@ class CustomMessage(message.Message):
         except KeyError:
             return []
 
+    @property
+    def groups(self):
+        try:
+            return self.body["groups"]
+        except KeyError:
+            return []
+
     @property
     def packages(self):
         try:
@@ -442,6 +461,14 @@ class CustomMessageTests(TestCase):
         self.assertIn("fedora_messaging_user_jcline", msg._headers)
         self.assertIn("fedora_messaging_user_abompard", msg._headers)
 
+    def test_groups(self):
+        """Assert groups are placed in the message headers."""
+        msg = CustomMessage(body={"groups": ["fedora-infra", "copr"]})
+
+        self.assertEqual(msg.groups, ["fedora-infra", "copr"])
+        self.assertIn("fedora_messaging_group_fedora-infra", msg._headers)
+        self.assertIn("fedora_messaging_group_copr", msg._headers)
+
     def test_packages(self):
         """Assert RPM packages are placed in the message headers."""
         msg = CustomMessage(body={"packages": ["kernel", "python-requests"]})
